package
Version:
v1.0.2
Opens a new window with list of versions in this module.
Published: Jul 19, 2025
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Filter[T any](list []T, filter func(T) bool) []T
func ToDelimitedString[T any](list []T) string
Source Files
¶
Click to show internal directories.
Click to hide internal directories.